@@ -1,6 +1,6 @@
 package Test::Magpie;
-BEGIN {
-  $Test::Magpie::VERSION = '0.05';
+{
+  $Test::Magpie::VERSION = '0.06';
 }
 # ABSTRACT: Spy on objects to achieve test doubles (mock testing)
 use strict;
@@ -28,9 +28,14 @@ sub verify {
 }
 
 sub mock {
+    return Mock->new if @_ == 0;
+
+    my $class;
+    $class = shift if @_ % 2;
     my %opts = @_;
-    my $mock = Mock->new;
-    return $mock;
+    $opts{class} = $class if defined $class;
+
+    return Mock->new(\%opts);
 }
 
 sub when {
@@ -59,8 +64,8 @@ sub at_most {
 
 1;
 
-
 __END__
+
 =pod
 
 =encoding utf-8
@@ -121,10 +126,13 @@ juicy details.
 
 =head1 FUNCTIONS
 
-=head2 mock
+=head2 mock([$blessed])
 
 Construct a new instance of a mock object.
 
+C<$blessed> is an optional argument to set the type that the mock object is
+blessed into. This value will be returned when C<ref()> is called on the object.
+
 =head2 verify($mock, [%options])
 
 Begin the verification process on a mock. Takes a mock object, and gives back a
@@ -174,10 +182,9 @@ Oliver Charles
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Oliver Charles <oliver.g.charles@googlemail.com>.
+This software is copyright (c) 2013 by Oliver Charles <oliver.g.charles@googlemail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
