@@ -1,6 +1,6 @@
 package Test::Magpie::Util;
-BEGIN {
-  $Test::Magpie::Util::VERSION = '0.05';
+{
+  $Test::Magpie::Util::VERSION = '0.06';
 }
 # ABSTRACT: Utilities used by Test::Magpie
 use strict;
@@ -10,7 +10,7 @@ use aliased 'Test::Magpie::ArgumentMatcher';
 use Scalar::Util qw( blessed );
 
 use Sub::Exporter -setup => {
-    exports => [qw( extract_method_name match )],
+    exports => [qw( extract_method_name has_caller_package match )],
 };
 
 sub extract_method_name {
@@ -19,6 +19,16 @@ sub extract_method_name {
     return $method;
 }
 
+sub has_caller_package {
+    my $package= shift;
+
+    my $level = 1;
+    while (my ($caller) = caller $level++) {
+        return 1 if $caller eq $package;
+    }
+    return;
+}
+
 sub match {
     my ($a, $b) = @_;
     return blessed($a)
@@ -28,9 +38,8 @@ sub match {
 
 1;
 
-
-
 __END__
+
 =pod
 
 =encoding utf-8
@@ -46,6 +55,10 @@ Test::Magpie::Util - Utilities used by Test::Magpie
 Internal. From a fully qualified method name such as Foo::Bar::baz, will return
 just the method name (in this example, baz).
 
+=head2 has_caller_package($package)
+
+Internal. Returns whether the given C<$package> is in the current call stack.
+
 =head2 match
 
 Internal. Match 2 values for equality
@@ -56,10 +69,9 @@ Oliver Charles
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Oliver Charles <oliver.g.charles@googlemail.com>.
+This software is copyright (c) 2013 by Oliver Charles <oliver.g.charles@googlemail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
